home | help
UMOUNT(8)		     System Manager's Manual		       UMOUNT(8)

NAME
     umount -- unmount file systems

SYNOPSIS
     umount [-fv] special | node | fsid
     umount -a | -A [-F fstab] [-fv] [-h host] [-t type]

DESCRIPTION
     The umount utility calls the unmount(2) system call to remove a file system
     from the file system tree.  The file system can be specified by its special
     device  or remote node (rhost:path), the path to the mount point node or by
     the file system ID fsid as reported by "mount -v".

     The options are as follows:

     -a      All the file systems described in fstab(5) are unmounted.

     -A      All the currently mounted file systems  except  the  root	are  un-
	     mounted.

     -F fstab
	     Specify the fstab file to use.

     -f      The file system is forcibly unmounted.  Active special devices con-
	     tinue  to	work,  but  all other files return errors if further ac-
	     cesses are attempted.  The root file system cannot be forcibly  un-
	     mounted.

     -h host
	     Only  file  systems  mounted  from  the  specified host will be un-
	     mounted.  This option implies the -A option and,  unless  otherwise
	     specified with the -t option, will only unmount NFS file systems.

     -t type
	     Is  used  to indicate the actions should only be taken on file sys-
	     tems of the specified type.  More than one type may be specified in
	     a comma separated list.  The list of file system types can be  pre-
	     fixed  with  "no" to specify the file system types for which action
	     should not be taken.  For example, the umount command:

		   umount -a -t nfs,nullfs

	     unmounts all file systems of the  type  NFS  and  NULLFS  that  are
	     listed in the fstab(5) file.

     -v      Verbose,  additional information is printed out as each file system
	     is unmounted.

ENVIRONMENT
     PATH_FSTAB  If the environment variable PATH_FSTAB is set,  all  operations
		 are  performed against the specified file.  PATH_FSTAB will not
		 be honored if the process environment or memory  address  space
		 is  considred	"tainted".   (See issetugid(2) for more informa-
		 tion.)

FILES
     /etc/fstab  file system table

SEE ALSO
     unmount(2), fstab(5), mount(8)

HISTORY
     A umount utility appeared in Version 6 AT&T UNIX.

FreeBSD 5.2.1			  July 18, 2003 		       UMOUNT(8)

home | help